import fs from "node:fs/promises";
import path from "node:path";
import process from "node:process";
import { outdent as javascript } from "outdent";
import { getExtensionConfiguration } from "./utils.js";
const createHandlerEntrypointSrc = ({ slug }) => {
    return javascript `
    import { extension } from "../../.ntli/index.js";

    extension._slug = "${slug}";

    export const handler = extension.baseHandler;
  `;
};
export const writeHandlerFunction = async ({ constants, netlifyConfig, }) => {
    if (constants.INTERNAL_FUNCTIONS_SRC === undefined) {
        throw new Error("The current version of the Netlify CLI is too old. Please update it using `npm -g install netlify-cli` and try again.");
    }
    // The netlify CLI:
    //
    // - In a regular repo, sets process.cwd() to the repository root and does not set PACKAGE_PATH
    // - In a monorepo, sets process.cwd() to the repository root and sets constants.PACKAGE_PATH to
    //   the package we're currently running `build` or `dev` on
    // - But, if `netlifyConfig.build.base` is set, then process.cwd() is set to that value, but
    //   constants.PACKAGE_PATH is still set.
    //
    // So, if a base is set, then we should use that to resolve the extension configuration. If a base
    // is not set, resolve extension configuration relative to the package path rather than the
    // repository root or we'll fail to resolve the correct extension configuration in monorepos.
    const packagePath = netlifyConfig.build.base ??
        path.resolve(process.cwd(), constants.PACKAGE_PATH ?? "");
    const config = await getExtensionConfiguration(packagePath);
    await fs.mkdir(constants.INTERNAL_FUNCTIONS_SRC, { recursive: true });
    await fs.writeFile(path.resolve(constants.INTERNAL_FUNCTIONS_SRC, "handler.js"), createHandlerEntrypointSrc({ slug: config.slug }));
};
//# sourceMappingURL=write_handler_function.js.map